@@ -83,7 +83,6 @@ class Data(object):
     def create(table, colums, comment='',show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
-
         return Data.Base_pool[base_id].create(table, colums, comment,show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
@@ -139,6 +138,14 @@ class Data(object):
             return
         return Data.Base_pool[base_id].query(sql, show_sql) if base_id in Data.Base_pool else None
 
+    @staticmethod
+    def get_cache(table,is_safe=True):
+        res = {}
+        all_data = Data.select(table,[])
+        for i in all_data:
+            res[i['id']] = 1
+        return res
+
     @staticmethod
     def map_all_db(base_id='default',show_manager_id=False,file_path='',file_name='db_frame.py'):
         try:
